@@ -1,5 +1,5 @@
 use crate::codegen::common::OrmliteCodegen;
-use crate::TableMeta;
+use crate::attr;
 use ormlite_core::query_builder::Placeholder;
 use proc_macro2::TokenStream;
 use quote::quote;
@@ -22,16 +22,13 @@ impl OrmliteCodegen for PostgresBackend {
         Placeholder::dollar_sign()
     }
 
-    fn impl_HasQueryBuilder(ast: &DeriveInput, attr: &TableMeta) -> TokenStream {
+    fn impl_Model__select(_ast: &DeriveInput, attr: &attr::TableMeta) -> TokenStream {
         let table_name = &attr.table_name;
-        let model = &ast.ident;
         let db = Self::database();
         quote! {
-            impl ::ormlite::model::HasQueryBuilder<#db> for #model {
-                fn select<'args>() -> ::ormlite::SelectQueryBuilder<'args, #db, Self> {
-                    ::ormlite::SelectQueryBuilder::new(::ormlite::query_builder::Placeholder::dollar_sign())
-                        .column(&format!("\"{}\".*", #table_name))
-                }
+            fn select<'args>() -> ::ormlite::query_builder::SelectQueryBuilder<'args, #db, Self> {
+                ::ormlite::query_builder::SelectQueryBuilder::new(::ormlite::query_builder::Placeholder::dollar_sign())
+                    .column(&format!("\"{}\".*", #table_name))
             }
         }
     }
